import type * as Types from './types';
export default class HttpClientAuth {
    private key;
    private secret;
    constructor(key?: string, secret?: string);
    permissions(): Promise<string[] | null>;
    balance(): Promise<{
        currency_code: Types.CurrencyCode;
        amount: number;
        available: number;
    }[] | null>;
    collateral(): Promise<{
        collateral: number;
        open_position_pnl: number;
        require_collateral: number;
        keep_rate: number;
    } | null>;
    coinIns(): Promise<{
        id: number;
        order_id: string;
        currency_code: Types.CurrencyCode;
        amount: number;
        address: string;
        tx_hash: string;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    coinOuts(): Promise<{
        id: number;
        order_id: string;
        currency_code: Types.CurrencyCode;
        amount: number;
        address: string;
        tx_hash: string;
        fee: number;
        additional_fee: number;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    bankAccounts(): Promise<{
        id: number;
        is_verified: boolean;
        bank_name: string;
        branch_name: string;
        account_type: string;
        account_number: string;
        account_name: string;
    }[] | null>;
    deposits(): Promise<{
        id: number;
        order_id: string;
        currency_code: "JPY";
        amount: number;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    withdraw(body: Types.Withdraw): Promise<unknown>;
    widthdrawals(): Promise<{
        id: number;
        order_id: string;
        currency_code: "JPY";
        amount: number;
        status: Types.CoinStatus;
        event_date: string;
    }[] | null>;
    sendChildOrder(body: Types.ChildOrderBody): Promise<unknown>;
    cancelAllChildOrders(product: Types.ProductCode): Promise<unknown>;
    positions(product: 'FX_BTC_JPY'): Promise<{
        product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
        side: "BUY" | "SELL";
        price: number;
        size: number;
        commission: number;
        swap_point_accumulate: number;
        require_collateral: number;
        open_date: string;
        leverage: number;
        pnl: number;
        sfd: number;
    }[] | null>;
    collateralHistory(): Promise<{
        id: number;
        currency_code: Types.CurrencyCode;
        change: number;
        amount: number;
        reason_code: string;
        date: string;
    }[] | null>;
    tradingCommission(product: Types.ProductCode): Promise<{
        commission_rate: number;
    } | null>;
    private get;
    private post;
    private request;
}
