var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import fetch, { Headers, Request } from 'node-fetch';
import { URL } from 'url';
import { createHmac } from 'crypto';
// eslint-disable-next-line import/no-extraneous-dependencies
require('dotenv').config();
export default class HttpClientAuth {
    constructor(key, secret) {
        if (!key || !secret) {
            throw new Error('API key and/or secret are required.');
        }
        this.key = key;
        this.secret = secret;
    }
    permissions() {
        return this.get('getpermissions', {});
    }
    balance() {
        return this.get('getbalance', {});
    }
    collateral() {
        return this.get('getcollateral', {});
    }
    coinIns() {
        return this.get('getcoinins', {});
    }
    coinOuts() {
        return this.get('getcoinouts', {});
    }
    bankAccounts() {
        return this.get('getbankaccounts', {});
    }
    deposits() {
        return this.get('getdeposits', {});
    }
    withdraw(body) {
        return this.post('withdraw', body);
    }
    widthdrawals() {
        return this.get('getwidthdrawals', {});
    }
    sendChildOrder(body) {
        return this.post('sendchildorder', body);
    }
    cancelAllChildOrders(product) {
        return this.post('cancelallchildorders', { product_code: product });
    }
    positions(product) {
        return this.get('getpositions', { product_code: product });
    }
    collateralHistory() {
        return this.get('getcollateralhistory', {});
    }
    tradingCommission(product) {
        return this.get('gettradingcommission', { product_code: product });
    }
    get(method, params) {
        return this.request('GET', `/v1/me/${method}`, params);
    }
    post(method, params) {
        return this.request('POST', `/v1/me/${method}`, {}, params);
    }
    request(method, path, query, bodyObj) {
        return __awaiter(this, void 0, void 0, function* () {
            const url = new URL(`https://api.bitflyer.com${path}`);
            // eslint-disable-next-line no-return-assign
            if (query)
                Object.entries(query).forEach(([k, v]) => url.search = `${k}=${v}`);
            const timestamp = Date.now().toString();
            const body = bodyObj ? JSON.stringify(bodyObj) : '';
            const text = timestamp + method + url.pathname + url.search + body;
            const sign = createHmac('sha256', this.secret).update(text).digest('hex');
            const headers = new Headers();
            headers.append('ACCESS-KEY', this.key);
            headers.append('ACCESS-TIMESTAMP', timestamp);
            headers.append('ACCESS-SIGN', sign);
            headers.append('Content-Type', 'application/json');
            const request = method === 'GET'
                ? new Request(url.toString(), { headers, method })
                : new Request(url.toString(), { headers, method, body });
            const res = yield fetch(request);
            if (!res.ok) {
                throw new Error(res.statusText);
            }
            try {
                return yield res.json();
            }
            catch (_a) {
                return null;
            }
        });
    }
}
