import { createHmac, randomBytes } from 'crypto';
import { from, concat } from 'rxjs';
import { ignoreElements, shareReplay } from 'rxjs/operators';
import RealtimeClient from './realtime';
export default class RealtimeAuthClient extends RealtimeClient {
    constructor(key, secret) {
        if (!key || !secret) {
            throw new Error('API key and/or secret are required.');
        }
        super();
        this.auth$ = from(this.auth(key, secret)).pipe(shareReplay(), ignoreElements());
    }
    childOrderEvents() {
        return this.subscribe('child_order_events');
    }
    parentOrderEvents() {
        return this.subscribe('parent_order_events');
    }
    subscribe(channel) {
        return concat(this.auth$, super.subscribe(channel));
    }
    auth(key, secret) {
        const timestamp = Date.now();
        const nonce = randomBytes(16).toString('hex');
        const signature = createHmac('sha256', secret)
            .update(timestamp + nonce).digest('hex');
        return this.call('auth', {
            api_key: key, timestamp, nonce, signature,
        });
    }
}
