var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { concat, from, } from 'rxjs';
import { webSocket } from 'rxjs/webSocket';
import { filter, first, ignoreElements, map, share, } from 'rxjs/operators';
export default class RealtimeClient {
    constructor() {
        this.subscribed = {};
        this.subject = webSocket({
            url: 'wss://ws.lightstream.bitflyer.com/json-rpc',
            // eslint-disable-next-line global-require
            WebSocketCtor: require('ws'),
        });
        this.subject.subscribe();
    }
    unsubscribe() {
        this.subject.unsubscribe();
    }
    board(product) {
        return this.subscribe(`lightning_board_${product}`);
    }
    boardSnapshot(product) {
        return this.subscribe(`lightning_board_snapshot_${product}`);
    }
    executions(product) {
        return this.subscribe(`lightning_executions_${product}`);
    }
    ticker(product) {
        return this.subscribe(`lightning_ticker_${product}`);
    }
    subscribe(channel) {
        if (!this.subscribed[channel]) {
            this.subscribed[channel] = concat(from(this.call('subscribe', { channel })).pipe(ignoreElements()), this.channelMessage(channel));
        }
        return this.subscribed[channel];
    }
    channelMessage(channel) {
        return this.subject.asObservable().pipe(map((x) => x), filter((x) => { var _a; return x.method === 'channelMessage' && ((_a = x.params) === null || _a === void 0 ? void 0 : _a.channel) === channel; }), map((x) => { var _a; return (_a = x.params) === null || _a === void 0 ? void 0 : _a.message; }), share());
    }
    call(method, params) {
        return __awaiter(this, void 0, void 0, function* () {
            const id = Date.now().toString();
            this.subject.next({
                jsonrpc: '2.0',
                method,
                params,
                id,
            });
            const response = yield this.subject.pipe(filter((res) => res.id === id), first()).toPromise();
            if (response.error) {
                throw new Error(response.error.message);
            }
            return response;
        });
    }
}
