export declare const markets: ({
    product_code: "BTC_JPY";
    market_type: "Spot";
} | {
    product_code: "ETH_JPY";
    market_type: "Spot";
} | {
    product_code: "FX_BTC_JPY";
    market_type: "FX";
} | {
    product_code: "ETH_BTC";
    market_type: "Spot";
} | {
    product_code: "BCH_BTC";
    market_type: "Spot";
})[];
export declare type Market = typeof markets[0];
export declare type ProductCode = Market['product_code'];
export declare const board: {
    mid_price: number;
    bids: {
        price: number;
        size: number;
    }[];
    asks: {
        price: number;
        size: number;
    }[];
};
export declare type Board = typeof board;
export declare type BoardState = 'RUNNING' | 'CLOSED' | 'STARTING' | 'PREOPEN' | 'CIRCUIT BREAK' | 'AWAITING SQ' | 'MATURED';
export declare const ticker: {
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    state: BoardState;
    timestamp: string;
    tick_id: number;
    best_bid: number;
    best_ask: number;
    best_bid_size: number;
    best_ask_size: number;
    total_bid_depth: number;
    total_ask_depth: number;
    market_bid_size: number;
    market_ask_size: number;
    ltp: number;
    volume: number;
    volume_by_product: number;
};
export declare type Ticker = typeof ticker;
export declare const executions: ({
    id: number;
    side: "BUY";
    price: number;
    size: number;
    exec_date: string;
    buy_child_order_acceptance_id: string;
    sell_child_order_acceptance_id: string;
} | {
    id: number;
    side: "SELL";
    price: number;
    size: number;
    exec_date: string;
    buy_child_order_acceptance_id: string;
    sell_child_order_acceptance_id: string;
})[];
export declare type Execution = typeof executions[0];
export declare type Side = Execution['side'];
export declare type Health = 'NOMAL' | 'BUSY' | 'VERY BUSY' | 'SUPER BUSY' | 'NO ORDER' | 'STOP';
export declare const boardState: {
    health: Health;
    state: BoardState;
};
export declare const health: {
    status: Health;
};
export declare const chats: {
    nickname: string;
    message: string;
    date: string;
}[];
export declare type Chat = typeof chats[0];
export declare type CurrencyCode = 'JPY' | 'USD' | 'BTC' | 'BCH' | 'ETH' | 'ETC' | 'LTC' | 'MONA' | 'LSK' | 'XRP' | 'BAT' | 'XLM' | 'XEM';
export declare const balance: {
    currency_code: CurrencyCode;
    amount: number;
    available: number;
}[];
export declare type BalanceItem = typeof balance[0];
export declare const collateral: {
    collateral: number;
    open_position_pnl: number;
    require_collateral: number;
    keep_rate: number;
};
export declare type Collateral = typeof collateral;
export declare const collateralAccounts: ({
    currency_code: "JPY";
    amount: number;
} | {
    currency_code: "BTC";
    amount: number;
})[];
export declare type CollateralAccount = typeof collateralAccounts[0];
export declare type Address = {
    type: 'NORMAL';
    currency_code: CurrencyCode;
    address: string;
};
export declare const addresses: Address[];
export declare type CoinStatus = 'PENDING' | 'COMPLETED';
export declare const coinIns: {
    id: number;
    order_id: string;
    currency_code: CurrencyCode;
    amount: number;
    address: string;
    tx_hash: string;
    status: CoinStatus;
    event_date: string;
}[];
export declare type CoinIn = typeof coinIns[0];
export declare const coinOuts: {
    id: number;
    order_id: string;
    currency_code: CurrencyCode;
    amount: number;
    address: string;
    tx_hash: string;
    fee: number;
    additional_fee: number;
    status: CoinStatus;
    event_date: string;
}[];
export declare type CoinOut = typeof coinOuts[0];
export declare const banckAccounts: {
    id: number;
    is_verified: boolean;
    bank_name: string;
    branch_name: string;
    account_type: string;
    account_number: string;
    account_name: string;
}[];
export declare type BankAccount = typeof banckAccounts[0];
export declare const deposits: {
    id: number;
    order_id: string;
    currency_code: "JPY";
    amount: number;
    status: CoinStatus;
    event_date: string;
}[];
export declare type Deposit = typeof deposits[0];
export declare const withdraw: {
    currency_code: "JPY";
    bank_account_id: number;
    amount: number;
    code: string;
};
export declare type Withdraw = typeof withdraw;
export declare const withdrawals: {
    id: number;
    order_id: string;
    currency_code: "JPY";
    amount: number;
    status: CoinStatus;
    event_date: string;
}[];
export declare type Withdrawal = typeof withdrawals[0];
export declare type OrderType = 'LIMIT' | 'MARKET';
export declare type TimeInForce = 'GTC' | 'IOC' | 'FOK';
export declare const childOrderBody: {
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    child_order_type: OrderType;
    side: "BUY" | "SELL";
    price: number;
    size: number;
    minute_to_expire: number;
    time_in_force: TimeInForce;
};
export declare type ChildOrderBody = typeof childOrderBody;
export declare const cancelChildOrder1: {
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    child_order_id: string;
};
export declare const cancelChildOrder2: {
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    child_order_acceptance_id: string;
};
export declare type CancelChildOrder = typeof cancelChildOrder1 | typeof cancelChildOrder2;
declare type ConditionType = OrderType | 'STOP' | 'STOP_LIMIT' | 'TRAIL';
declare type OrderMethod = 'SIMPLE' | 'IFD' | 'OCO' | 'IFDOCO';
declare type ParentOrderParameterItem = {
    product_code: ProductCode;
    condition_type: ConditionType;
    side: Side;
    size: number;
    price: number;
    trigger_price: number;
    offset: number;
};
declare type ParentOrderParameter = Omit<ParentOrderParameterItem & {
    condition_type: 'LIMIT';
}, 'trigger_price' | 'offset'> | Omit<ParentOrderParameterItem & {
    condition_type: 'MARKET';
}, 'price' | 'trigger_price' | 'offset'> | Omit<ParentOrderParameterItem & {
    condition_type: 'STOP';
}, 'price' | 'offset'> | Omit<ParentOrderParameterItem & {
    condition_type: 'STOP_LIMIT';
}, 'offset'> | Omit<ParentOrderParameterItem & {
    condition_type: 'TRAIL';
}, 'price' | 'trigger_price'>;
declare type ParentOrderItem = {
    order_method: OrderMethod;
    minute_to_expire: number;
    time_in_force: TimeInForce;
    parameters: ParentOrderParameter[];
};
export declare type ParentOrderBody = ParentOrderItem & {
    order_method: 'SIMPLE';
    parameters: [ParentOrderParameter];
} | ParentOrderItem & {
    order_method: 'IFD' | 'OCO';
    parameters: [ParentOrderParameter, ParentOrderParameter];
} | ParentOrderItem & {
    order_method: 'IFDOCO';
    parameters: [ParentOrderParameter, ParentOrderParameter, ParentOrderParameter];
};
export declare const parentOrderBody: ParentOrderBody;
export declare const cancelParentOrder1: {
    product_code: string;
    parent_order_id: string;
};
export declare const cancelParentOrder2: {
    product_code: string;
    parent_order_acceptance_id: string;
};
export declare type CancelParentOrder = typeof cancelChildOrder1 | typeof cancelChildOrder2;
export declare const cancelAllChildOrders: {
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
};
export declare type CancelAllChildOrders = typeof cancelAllChildOrders;
export declare type OrderState = 'ACTIVE' | 'COMPLETED' | 'CANCELED' | 'EXPIRED' | 'REJECTED';
export declare const childOrders: {
    id: number;
    child_order_id: string;
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    side: "BUY" | "SELL";
    child_order_type: OrderType;
    price: number;
    average_price: number;
    size: number;
    child_order_state: OrderState;
    expire_date: string;
    child_order_date: string;
    child_order_acceptance_id: string;
    outstanding_size: number;
    cancel_size: number;
    executed_size: number;
    total_commission: number;
}[];
export declare type ChildOrder = typeof childOrders[0];
export declare const parentOrders: ({
    id: number;
    parent_order_id: string;
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    side: "BUY" | "SELL";
    parent_order_type: ConditionType;
    price: number;
    average_price: number;
    size: number;
    parent_order_state: OrderState;
    expire_date: string;
    parent_order_date: string;
    parent_order_acceptance_id: string;
    outstanding_size: number;
    cancel_size: number;
    executed_size: number;
    total_commission: number;
} | {
    id: number;
    parent_order_id: string;
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    side: "BUY" | "SELL";
    parent_order_type: OrderMethod;
    price: number;
    average_price: number;
    size: number;
    parent_order_state: string;
    expire_date: string;
    parent_order_date: string;
    parent_order_acceptance_id: string;
    outstanding_size: number;
    cancel_size: number;
    executed_size: number;
    total_commission: number;
})[];
export declare type ParentOrders = typeof parentOrders;
export declare type ParentOrder = {
    id: number;
    parent_order_id: string;
    parent_order_acceptance_id: string;
    order_method: OrderMethod;
    expire_date: string;
    time_in_force: TimeInForce;
    parameters: ParentOrderParameterItem[];
};
export declare const parentOrder: ParentOrder;
export declare const myExecutions: {
    id: number;
    child_order_id: string;
    side: "BUY" | "SELL";
    price: number;
    size: number;
    commission: number;
    exec_date: string;
    child_order_acceptance_id: string;
}[];
export declare type MyExecution = typeof myExecutions[0];
export declare type TradeType = 'BUY' | 'SELL' | 'DEPOSIT' | 'WITHDRAW' | 'FEE' | 'POST_COLL' | 'CANCEL_COLL' | 'PAYMENT' | 'TRANSFER';
export declare const balanceHistory: {
    id: number;
    trade_date: string;
    event_date: string;
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    currency_code: CurrencyCode;
    trade_type: TradeType;
    price: number;
    amount: number;
    quantity: number;
    commission: number;
    balance: number;
    order_id: string;
}[];
export declare type BalanceHistoryItem = typeof balanceHistory[0];
export declare const positions: {
    product_code: "BTC_JPY" | "ETH_JPY" | "FX_BTC_JPY" | "ETH_BTC" | "BCH_BTC";
    side: "BUY" | "SELL";
    price: number;
    size: number;
    commission: number;
    swap_point_accumulate: number;
    require_collateral: number;
    open_date: string;
    leverage: number;
    pnl: number;
    sfd: number;
}[];
export declare type Position = typeof positions[0];
export declare const collateralHistory: {
    id: number;
    currency_code: CurrencyCode;
    change: number;
    amount: number;
    reason_code: string;
    date: string;
}[];
export declare type CollateralHistoryItem = typeof collateralHistory[0];
export declare const tradingCommission: {
    commission_rate: number;
};
export declare type TradingCommission = typeof tradingCommission;
export {};
